summaryrefslogtreecommitdiff
path: root/bos-meta-bootstrap.sh
diff options
context:
space:
mode:
authorGianni Ceccarelli <gianni.ceccarelli@broadbean.com>2023-07-27 18:00:32 +0100
committerGianni Ceccarelli <gianni.ceccarelli@broadbean.com>2023-07-27 18:00:32 +0100
commit13cb1cb9a8414012ab9f4737354702a352b44e92 (patch)
tree0b5e95f472c97f9420b01d572f51d27c9b7d097c /bos-meta-bootstrap.sh
parentmaster loader (diff)
downloadbash-object-system-13cb1cb9a8414012ab9f4737354702a352b44e92.tar.gz
bash-object-system-13cb1cb9a8414012ab9f4737354702a352b44e92.tar.bz2
bash-object-system-13cb1cb9a8414012ab9f4737354702a352b44e92.zip
BROKEN
I'm trying to get `invoke` to set up attributes it fails because the attributes for the `mro` attribute meta-object are stored in `bos__attribute__attribute_5fname__bos_2fmeta_2fclass__bos_2fmeta_2fattribute__7__` &c, with the wrong defining class (`attribute_name` is defined in `bos/meta/attribute`, not `/class`!)
Diffstat (limited to 'bos-meta-bootstrap.sh')
-rw-r--r--bos-meta-bootstrap.sh22
1 files changed, 11 insertions, 11 deletions
diff --git a/bos-meta-bootstrap.sh b/bos-meta-bootstrap.sh
index f301812..b476f38 100644
--- a/bos-meta-bootstrap.sh
+++ b/bos-meta-bootstrap.sh
@@ -76,14 +76,14 @@ $bos_meta_attribute_meta_class_instance set-attribute-by-name 'associated_class'
# now we set the attributes for bos/meta/class!
## this is the `class-attributes` meta-attribute
bos/meta/class/create-object-into bos_meta_attribute_instance bos/meta/attribute
attribute_type='scalar'
-associated_class='bos/meta/class'
+associated_class='bos/meta/attribute'
attribute_name='attribute_name'
-$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" 'class-attributes'
+$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" 'class_attributes'
attribute_name='attribute_type'
$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" assoc
@@ -91,16 +91,16 @@ $bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" assoc
attribute_name='associated_class'
$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" bos/meta/class
-$bos_meta_class_meta_class_instance set-attribute-by-name 'class-attributes' "$bos_meta_attribute_instance"
+$bos_meta_class_meta_class_instance set-attribute-by-name 'class_attributes' "$bos_meta_attribute_instance"
-## this is the `class-name` meta-attribute
+## this is the `class_name` meta-attribute
bos/meta/class/create-object-into bos_meta_attribute_instance bos/meta/attribute
attribute_type='scalar'
-associated_class='bos/meta/class'
+associated_class='bos/meta/attribute'
attribute_name='attribute_name'
-$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" 'class-name'
+$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" 'class_name'
attribute_name='attribute_type'
$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" scalar
@@ -108,19 +108,19 @@ $bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" scalar
attribute_name='associated_class'
$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" bos/meta/class
-$bos_meta_class_meta_class_instance set-attribute-by-name 'class-name' "$bos_meta_attribute_instance"
+$bos_meta_class_meta_class_instance set-attribute-by-name 'class_name' "$bos_meta_attribute_instance"
## this is the `isa` meta-attribute
bos/meta/class/create-object-into bos_meta_attribute_instance bos/meta/attribute
attribute_type='scalar'
-associated_class='bos/meta/class'
+associated_class='bos/meta/attribute'
attribute_name='attribute_name'
$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" 'isa'
attribute_name='attribute_type'
-$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" arary
+$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" array
attribute_name='associated_class'
$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" bos/meta/class
@@ -137,7 +137,7 @@ attribute_name='attribute_name'
$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" 'mro'
attribute_name='attribute_type'
-$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" arary
+$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" array
attribute_name='associated_class'
$bos_meta_attribute_instance set-value "$bos_meta_attribute_instance" bos/meta/class
@@ -76,14 +76,14 @@ $bos_meta_attribute_meta_class_instance set-attribute-by-name 'associated_class'
# now we set the attributes for bos/meta/class!
-## this is the `class-attributes` meta-attribute
+## this is the `class_attributes` meta-attribute
bos/meta/class/create-object-into bos_meta_attribute_instance bos/meta/attribute
attribute_type='scalar'